@@ -35,7 +35,7 @@ namespace Gobby
 
 		IconManager();
 
-		const Glib::RefPtr<Gdk::Pixbuf> gobby;
+		//const Glib::RefPtr<Gdk::Pixbuf> gobby;
 		const Glib::RefPtr<Gdk::Pixbuf> userlist;
 		const Glib::RefPtr<Gdk::Pixbuf> doclist;
 		const Glib::RefPtr<Gdk::Pixbuf> chat;
