@@ -520,7 +520,7 @@ void Gobby::Window::on_about()
 		"Copyright (C) 2005-2008 0x539 dev group <crew@0x539.de>"
 	);
 
-	dlg.set_logo(m_icon_mgr.gobby);
+	dlg.set_logo_icon_name("gobby");
 
 	std::deque<Glib::ustring> authors;
 	authors.push_back("Developers:");
@@ -542,7 +542,9 @@ void Gobby::Window::on_about()
 	dlg.set_artists(artists);
 
 	dlg.set_license(
-		"This program is free software; you can redistribute it\n"
+		// Please note in the translation that only the English version is
+		// legally binding.
+		_("This program is free software; you can redistribute it\n"
 		"and/or modify it under the terms of the GNU General Public\n"
 		"License as published by the Free Software Foundation; either\n"
 		"version 2 of the License, or (at your option) any later\n"
@@ -551,7 +553,7 @@ void Gobby::Window::on_about()
 		"This program is distributed in the hope that it will be\n"
 		"useful, but WITHOUT ANY WARRANTY; without even the implied\n"
 		"warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR\n"
-		"PURPOSE.  See the GNU General Public License for more details."
+		"PURPOSE.  See the GNU General Public License for more details.")
 	);
 	dlg.run();
 }
@@ -700,14 +702,12 @@ void Gobby::Window::on_document_open()
 		m_last_path = dlg.get_current_folder();
 		// Open chosen files
 		std::list<Glib::ustring> list = dlg.get_filenames();
+                std::string encoding = dlg.get_selector().get_encoding();
 		for(std::list<Glib::ustring>::iterator iter = list.begin();
 		    iter != list.end();
 		    ++ iter)
 		{
-			open_local_file(
-				*iter,
-				dlg.get_selector().get_encoding()
-			);
+			open_local_file(*iter, encoding);
 		}
 	}
 }
@@ -1427,7 +1427,8 @@ void Gobby::Window::open_local_file(const Glib::ustring& file,
 		convert2unix(utf8_content);
 
 		m_buffer->document_create(
-			Glib::path_get_basename(file), "UTF-8", utf8_content
+			Glib::filename_to_utf8(Glib::path_get_basename(file)),
+			"UTF-8", utf8_content
 		);
 
 		// Clear local path
